@@ -87,6 +87,10 @@ class FeaturesTest(TestCase, SharedTestModule):
         self.assertEqual(response.status_code, 200)
         self.client.get(self.post.get_absolute_url(), follow=True)
         self.assertContains(response, 'test signature')
+        # Test empty signature
+        values['signature'] = ''
+        response = self.client.post(reverse('pybb:edit_profile'), data=values, follow=True)
+        self.assertEqual(len(response.context['form'].errors), 0)
 
     def test_pagination_and_topic_addition(self):
         for i in range(0, defaults.PYBB_FORUM_PAGE_SIZE + 3):
@@ -592,4 +596,19 @@ class AttachmentTest(TestCase, SharedTestModule):
 
     def tearDown(self):
         defaults.PYBB_ATTACHMENT_ENABLE = self.PYBB_ATTACHMENT_ENABLE
-        defaults.PYBB_PREMODERATION = self.ORIG_PYBB_PREMODERATION
\ No newline at end of file
+        defaults.PYBB_PREMODERATION = self.ORIG_PYBB_PREMODERATION
+
+class FiltersTest(TestCase, SharedTestModule):
+    def setUp(self):
+        self.create_user()
+        self.create_initial(post=False)
+
+    def test_filters(self):
+        add_post_url = reverse('pybb:add_post', kwargs={'topic_id': self.topic.id})
+        self.login_client()
+        response = self.client.get(add_post_url)
+        values = self.get_form_values(response)
+        values['body'] = u'test\n \n \n\nmultiple empty lines\n'
+        response = self.client.post(add_post_url, values, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(Post.objects.all()[0].body, u'test\nmultiple empty lines')
\ No newline at end of file
